@@ -52,7 +52,9 @@ package com.openexchange.caldav.mixins;
 import com.openexchange.caldav.CaldavProtocol;
 import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.exception.OXException;
+import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.UserizedFolder;
+import com.openexchange.folderstorage.database.contentType.CalendarContentType;
 import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 
 /**
@@ -90,7 +92,9 @@ public class ScheduleDefaultCalendarURL extends SingleXMLPropertyMixin {
     protected String getValue() {
         String value = null;
         try {
-            UserizedFolder defaultFolder = factory.getState().getDefaultFolder();
+            String treeID = factory.getConfigValue("com.openexchange.caldav.tree", FolderStorage.REAL_TREE_ID);
+            UserizedFolder defaultFolder = factory.getFolderService().getDefaultFolder(
+                factory.getUser(), treeID, CalendarContentType.getInstance(), factory.getSession(), null);
             if (null != defaultFolder) {
                 value = defaultFolder.getID();
             }
