@@ -201,7 +201,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                     String timeZone = null != object.getTimezone() ? object.getTimezone() : factory.getUser().getTimeZone();
                     List<CalendarDataObject> appointments = factory.getIcalParser().parseAppointments(exceptionICal, TimeZone.getTimeZone(timeZone), factory.getContext(), new ArrayList<ConversionError>(), new ArrayList<ConversionWarning>()).getImportedObjects();
                     if (null == appointments || 1 != appointments.size() || null == appointments.get(0).getRecurrenceDatePosition()) {
-                        throw protocolException(getUrl(), HttpServletResponse.SC_NOT_FOUND);
+                        throw protocolException(getUrl(), OXException.notFound(recurrenceID), HttpServletResponse.SC_NOT_FOUND);
                     }
                     /*
                      * get matching change exception
@@ -210,7 +210,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                     CalendarDataObject[] originalExceptions = parent.loadChangeExceptions(object, false);
                     CalendarDataObject targetedException = getMatchingException(originalExceptions, recurrenceDatePosition);
                     if (null == targetedException) {
-                        throw protocolException(getUrl(), HttpServletResponse.SC_NOT_FOUND);
+                        throw protocolException(getUrl(), OXException.notFound(recurrenceID), HttpServletResponse.SC_NOT_FOUND);
                     }
                     objects.add(targetedException);
                 }
@@ -269,7 +269,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
             Appointment originalAppointment = phantomMaster ? object : parent.load(object, false);
             Date clientLastModified = object.getLastModified();
             if (clientLastModified.before(originalAppointment.getLastModified())) {
-                throw protocolException(getUrl(), HttpServletResponse.SC_CONFLICT);
+                throw protocolException(getUrl(), OXException.conflict(), HttpServletResponse.SC_CONFLICT);
             }
             /*
              * check folder permissions beforehand
@@ -277,7 +277,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
             int ownPermissions = parent.getFolder().getOwnPermission().getWritePermission();
             if (Permission.WRITE_OWN_OBJECTS > ownPermissions ||
                 Permission.WRITE_OWN_OBJECTS == ownPermissions && originalAppointment.getCreatedBy() != factory.getSession().getUserId()) {
-                throw protocolException(getUrl(), HttpServletResponse.SC_FORBIDDEN);
+                throw protocolException(getUrl(), OXException.noPermissionForFolder(), HttpServletResponse.SC_FORBIDDEN);
             }
             if (false == phantomMaster && null != appointmentToSave) {
                 /*
@@ -285,6 +285,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                  */
                 handlePrivateComments(appointmentToSave);
                 ReminderObject nextReminder = handleReminders(originalAppointment, appointmentToSave, exceptionsToSave);
+                boolean confirmationChange = isConfirmationChange(originalAppointment, appointmentToSave);
                 /*
                  * explicitly update user's confirmation to trigger scheduling-related notifications
                  */
@@ -310,10 +311,11 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                         Patches.Incoming.addUserParticipantIfEmpty(factory.getSession().getUserId(), appointmentToSave);
                     }
                 }
-                checkForExplicitRemoves(originalAppointment, appointmentToSave);
+                checkForExplicitRemoves(originalAppointment, appointmentToSave, confirmationChange);
                 if (false == containsChanges(originalAppointment, appointmentToSave)) {
                     LOG.debug("No further changes detected in {}, skipping update.", appointmentToSave);
                 } else {
+                    CalendarDataObject appointmentToSave = this.appointmentToSave.clone();
                     Appointment[] hardConflicts = getAppointmentInterface().updateAppointmentObject(appointmentToSave, parentFolderID, clientLastModified, checkPermissions);
                     if (null != hardConflicts && 0 < hardConflicts.length) {
                         throw new PreconditionException(
@@ -321,6 +323,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                     }
                     if (null != appointmentToSave.getLastModified()) {
                         clientLastModified = appointmentToSave.getLastModified();
+                        this.appointmentToSave.setLastModified(clientLastModified);
                     }
                 }
                 /*
@@ -371,7 +374,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                      */
                     exceptionToSave.setObjectID(originalException.getObjectID());
                     exceptionToSave.setParentFolderID(originalException.getParentFolderID());
-                    checkForExplicitRemoves(originalException, exceptionToSave);
+                    checkForExplicitRemoves(originalException, exceptionToSave, isConfirmationChange(originalException, exceptionToSave));
                     if (false == Patches.Incoming.tryRestoreParticipants(originalException, exceptionToSave)) {
                         Patches.Incoming.patchParticipantListRemovingAliases(factory, exceptionToSave);
                         Patches.Incoming.patchParticipantListRemovingDoubleUsers(exceptionToSave);
@@ -388,6 +391,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                      */
                     exceptionToSave.setObjectID(object.getObjectID());
                     exceptionToSave.setParentFolderID(object.getParentFolderID());
+                    checkForExplicitRemoves(originalAppointment, exceptionToSave, isConfirmationChange(originalAppointment, exceptionToSave));
                     if (false == Patches.Incoming.tryRestoreParticipants(originalAppointment, exceptionToSave)) {
                         Patches.Incoming.patchParticipantListRemovingAliases(factory, exceptionToSave);
                         Patches.Incoming.patchParticipantListRemovingDoubleUsers(exceptionToSave);
@@ -485,12 +489,18 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
             }
             handlePrivateComments(appointmentToSave);
             ReminderObject nextReminder = handleReminders(null, appointmentToSave, null);
-            Appointment[] hardConflicts = getAppointmentInterface().insertAppointmentObject(appointmentToSave);
-            if (null != hardConflicts && 0 < hardConflicts.length) {
-                throw new PreconditionException(
-                    DAVProtocol.CAL_NS.getURI(), "allowed-organizer-scheduling-object-change", getUrl(), HttpServletResponse.SC_FORBIDDEN);
+            Date clientLastModified;
+            {
+                CalendarDataObject appointmentToSave = this.appointmentToSave.clone();
+                Appointment[] hardConflicts = getAppointmentInterface().insertAppointmentObject(appointmentToSave);
+                if (null != hardConflicts && 0 < hardConflicts.length) {
+                    throw new PreconditionException(
+                        DAVProtocol.CAL_NS.getURI(), "allowed-organizer-scheduling-object-change", getUrl(), HttpServletResponse.SC_FORBIDDEN);
+                }
+                clientLastModified = appointmentToSave.getLastModified();
+                this.appointmentToSave.setLastModified(clientLastModified);
+                this.appointmentToSave.setObjectID(appointmentToSave.getObjectID());
             }
-            Date clientLastModified = appointmentToSave.getLastModified();
             /*
              * process attachments & reminders
              */
@@ -516,7 +526,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                 exception.setObjectID(appointmentToSave.getObjectID());
                 Patches.Incoming.removeParticipantsForPrivateAppointmentInPublicfolder(
                     factory.getSession().getUserId(), parent.getFolder(), exception);
-                hardConflicts = getAppointmentInterface().updateAppointmentObject(exception, parentFolderID, clientLastModified);
+                Appointment[] hardConflicts = getAppointmentInterface().updateAppointmentObject(exception, parentFolderID, clientLastModified);
                 if (null != hardConflicts && 0 < hardConflicts.length) {
                     throw new PreconditionException(
                         DAVProtocol.CAL_NS.getURI(), "allowed-organizer-scheduling-object-change", getUrl(), HttpServletResponse.SC_FORBIDDEN);
@@ -807,7 +817,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
             diff.anyFieldChangedOf(RECURRENCE_FIELDS);
     }
 
-    private void checkForExplicitRemoves(Appointment oldAppointment, CalendarDataObject updatedAppointment) {
+    private void checkForExplicitRemoves(Appointment oldAppointment, CalendarDataObject updatedAppointment, boolean confirmationChange) {
         /*
          * reset previously set appointment fields
          */
@@ -866,8 +876,7 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                 updatedAppointment.removeShownAs();
             } else if ((updatedAppointment.containsOrganizerId() && factory.getSession().getUserId() != updatedAppointment.getOrganizerId() ||
                 updatedAppointment.containsOrganizer() && null != updatedAppointment.getOrganizer() &&
-                false == updatedAppointment.getOrganizer().equals(factory.getUser().getMail())) &&
-                isConfirmationChange(oldAppointment, updatedAppointment)) {
+                false == updatedAppointment.getOrganizer().equals(factory.getUser().getMail())) && confirmationChange) {
                 // don't change "shown as", since iCal clients tend to change the transparency on accept/decline actions of participants
                 updatedAppointment.removeShownAs();
             }
@@ -955,8 +964,11 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
      * @throws WebdavProtocolException If not handled
      */
     private void handleOnCreate(WebdavProtocolException e) throws WebdavProtocolException {
-        if (null != e && null != e.getCause() && OXException.class.isInstance(e.getCause()) &&
-            "APP-0100".equals(((OXException)e.getCause()).getErrorCode())) {
+        if (null == e) {
+            return;
+        }
+        if ("APP-0100".equals(e.getErrorCode()) ||
+            null != e.getCause() && OXException.class.isInstance(e.getCause()) && "APP-0100".equals(((OXException)e.getCause()).getErrorCode())) {
             /*
              * Cannot insert appointment (...). An appointment with the unique identifier (...) already exists.
              */
@@ -966,10 +978,11 @@ public class AppointmentResource extends CalDAVResource<Appointment> {
                     CalendarDataObject existingAppointment = getAppointmentInterface().getObjectById(objectID);
                     if (isUpdate(appointmentToSave, existingAppointment) &&
                         PrivateType.getInstance().equals(parent.getFolder().getType())) {
-                        LOG.debug("Considering appointment with UID '{}', sequence {} as update for appointment with object ID {}, sequence {}.", appointmentToSave.getUid(), appointmentToSave.getSequence(), objectID, existingAppointment.getSequence());
+                        LOG.debug("Considering appointment with UID '{}', sequence {} as update for appointment with object ID {}, sequence {}.",
+                            appointmentToSave.getUid(), appointmentToSave.getSequence(), objectID, existingAppointment.getSequence());
                         this.object = existingAppointment;
                         appointmentToSave.setObjectID(objectID);
-                        appointmentToSave.removeParentFolderID();
+                        appointmentToSave.setParentFolderID(parentFolderID);
                         this.saveObject(false); // update instead of create
                         return; // handled
                     }
