@@ -92,6 +92,7 @@ import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.java.Streams;
 import com.openexchange.java.Strings;
+import com.openexchange.login.Interface;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProperty;
@@ -148,6 +149,11 @@ public abstract class CalDAVFolderCollection<T extends CalendarObject> extends C
         }
     }
 
+    @Override
+    public String getPushTopic() {
+        return null != folder ? "ox:" + Interface.CALDAV.toString().toLowerCase() + ":" + folder.getID() : null;
+    }
+
     protected abstract boolean isSupported(T object) throws OXException;
 
     protected abstract List<T> getObjectsInRange(Date from, Date until) throws OXException;
