@@ -56,6 +56,7 @@ import com.openexchange.carddav.GroupwareCarddavFactory;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.groupware.container.Contact;
+import com.openexchange.login.Interface;
 import com.openexchange.webdav.protocol.WebdavPath;
 import com.openexchange.webdav.protocol.WebdavProtocolException;
 
@@ -81,6 +82,11 @@ public class AggregatedCollection extends CardDAVCollection {
         this.displayName = displayName;
     }
 
+    @Override
+    public String getPushTopic() {
+        return "ox:" + Interface.CARDDAV.toString().toLowerCase();
+    }
+
     @Override
     protected Collection<Contact> getDeletedObjects(Date since) throws OXException {
         Collection<Contact> contacts = super.getDeletedObjects(since);
